/*
 * Project name:
     RTC_Write (Demonstration on working with the RTC Module and Software I2C routines)
 * Copyright:
     (c) Mikroelektronika, 2010.
 * Revision History:
     20071210:
       - initial release;
     20101130:
       - adapted for PRO compilers (TL);
 * Description:
     This project is simple demonstration how to read date and time from
     Dallas(Maxim Integrated Products) DS1307 RTC2 (real-time clock).
     Date and time are read from the RTC2 every 1 second and printed on LCD.
 * Test configuration:
     MCU:             AT89S8253
                      http://www.atmel.com/dyn/resources/prod_documents/doc3286.pdf
     Dev.Board:       Easy8051 v6
                      http://www.mikroe.com/eng/products/view/329/easy8051-v6-development-system/
     Oscillator:      External Clock - 10.0000 MHz
     Ext. Modules:    RTC2 extra board on PORT1
                      http://www.mikroe.com/eng/products/view/197/rtc2-board/
     SW:              mikroC for 8051 v2.2
                      http://www.mikroe.com/eng/products/view/232/mikroc-pro-for-8051/
 * NOTES:
     - Pull-up I2C communication lines (P1.0 and P1.1)
     - Turn off I2C communication lines (PORT1) LEDs.
     - Turn on LCD backlight switch on development board.
     - In order to use the example, address pin D0 of DS1307 must be set to 0V.
       (on mikroElektronika's RTC extra board this is done by default)
*/

char seconds, minutes, hours, date, month;  // Global date/time variables
unsigned int year;
unsigned int RTCModuleAddress, YearOffset; // RTC chip description variables

//#define PCF8583         // Uncomment this line if you use PCF8583 RTC chip (mE RTC extra board)
#define DS1307          // Uncomment this line if you use DS1307 RTC chip (mE RTC2 extra board)

// Software I2C connections
sbit Soft_I2C_Scl at P1_0_bit;
sbit Soft_I2C_Sda at P1_1_bit;
// End Software I2C connections

//------------------ Performs project-wide init
void Init_Main() {

  #ifdef DS1307
    RTCModuleAddress   = 0xD0;
    YearOffset         = 2000;
  #endif

  Soft_I2C_Init();           // Initialize Soft I2C communication
}

//--------------------- Writes time and date information to DS1307 RTC
void Write_Time_DS1307() {
  char byte_to_write;

  Soft_I2C_Start();                   // Issue start signal
  Soft_I2C_Write(RTCModuleAddress);   // RTC module address + write (R#/W = 0)
  Soft_I2C_Write(0);                  // Start from seconds byte

  byte_to_write = Dec2Bcd(seconds);                            // Prepare seconds byte
  Soft_I2C_Write(byte_to_write);                               // Write seconds byte

  byte_to_write = Dec2Bcd(minutes);                            // Prepare minutes byte
  Soft_I2C_Write(byte_to_write);                               // Write minutes byte

  byte_to_write = Dec2Bcd(hours);                              // Prepare hours byte (24h format)
  Soft_I2C_Write(byte_to_write);                               // Write hours byte
  
  Soft_I2C_Write(0);                                           // Write 0 to weekday byte
  
  byte_to_write = Dec2Bcd(date);                               // Prepare date byte
  Soft_I2C_Write(byte_to_write);                               // Write date byte
  
  byte_to_write = Dec2Bcd(month);                              // Prepare month byte
  Soft_I2C_Write(byte_to_write);                               // Write month byte

  byte_to_write = Dec2Bcd(year - YearOffset);                  // Prepare year byte
  Soft_I2C_Write(byte_to_write);                               // Write year byte

  Soft_I2C_Stop();                    // Issue stop signal
}

//--------------------- Writes time and date information to RTC
void Write_Time() {
   #ifdef DS1307
    Write_Time_DS1307();
  #endif
}

//----------------- Main procedure
void main() {

  Delay_ms(2000);

  Init_Main();               // Perform initialization
  
  date    = 31;
  month   = 12;
  year    = 2009;
  hours   = 23;
  minutes = 59;
  seconds = 40;

  Write_Time();              // Write time to RTC

}
