/* Project name:
     RTC_Write (Demonstration on working with the RTC Module and Software I2C routines)
 * Copyright:
     (c) Mikroelektronika, 2005-2010.
 * Revision History:
     20080930:
       - initial release;
     20101129:
       - adapted for PRO compilers
 * Description:
      This project is simple demonstration how to set date and time on DS1307
      RTC (real-time clock).
 * Test configuration:
     MCU:             ATmega16
                      http://www.atmel.com/dyn/resources/prod_documents/doc2466.pdf
     Dev.Board:       EasyAVR6
                      http://www.mikroe.com/eng/products/view/321/easyavr6-development-system/
     Oscillator:      External Clock, 8.0000 MHz
     Ext. Modules:    ac:RTC2 on PORTC
     SW:              mikroC PRO for AVR
                      http://www.mikroe.com/eng/products/view/228/mikroc-pro-for-avr/
 * NOTES:
     - I2C communication lines should be connected to pull-up resistors.
     - Turn off LEDs connected to I2C communication lines.
     - In order to use the example, address pin D0 of DS1307 must be set to 0V.
       (on mikroElektronika's RTC module this is done by default)
*/

// Software I2C connections
sbit Soft_I2C_Scl_Output at PORTC0_bit;
sbit Soft_I2C_Sda_Output at PORTC1_bit;
sbit Soft_I2C_Scl_Input at PINC0_bit;
sbit Soft_I2C_Sda_Input at PINC1_bit;
sbit Soft_I2C_Scl_Direction at DDC0_bit;
sbit Soft_I2C_Sda_Direction at DDC1_bit;
// End Software I2C connections

void main() {

   Delay_ms(1000);
   Soft_I2C_Init();         // initialize full master mode
   Soft_I2C_Start();        // issue start signal
   Soft_I2C_Write(0xD0);    // address DS1307
   Soft_I2C_Write(0);       // start from word at address (REG0)
   Soft_I2C_Write(0x80);    // write $80 to REG0. (pause counter + 0 sec)
   Soft_I2C_Write(0);       // write 0 to minutes word to (REG1)
   Soft_I2C_Write(0);       // write 17 to hours word (24-hours mode)(REG2)
   Soft_I2C_Write(0x30);    // write 2 - Monday (REG3)
   Soft_I2C_Write(0x12);    // write 4 to date word (REG4)
   Soft_I2C_Write(0x24);    // write 5 (May) to month word (REG5)
   Soft_I2C_Write(0x08);    // write 09 to year word (REG6)
   Soft_I2C_Stop();         // issue stop signal

   Soft_I2C_Start();        // issue start signal
   Soft_I2C_Write(0xD0);    // address DS1307
   Soft_I2C_Write(0);       // start from word at address 0
   Soft_I2C_Write(0);       // write 0 to REG0 (enable counting + 0 sec)
   Soft_I2C_Stop();         // issue stop signal
}//~!