/* Project name:
     RTC2_Write (Writing date/time data to DS1307 through I2C)
 * Copyright:
     (c) MikroElektronika, 2005-2010
 * Revision History:
     20090504:
       -  Author: Igor Stancic;
     20101126:
       -  Adapted for PRO compilers (TL);
 * Description:
     This project is simple demonstration how to read date and time from DS1307
     RTC (real-time clock). The code MCU use MSSP module at PORTC.
     Date and time are printed at LCD.
 * Test configuration:
     MCU:             dsPIC30F4013
                      http://ww1.microchip.com/downloads/en/DeviceDoc/70138G.pdf
     Dev.Board:       EasydsPIC6
                      http://www.mikroe.com/eng/products/view/434/easydspic6-development-system/
     Oscillator:      HS-PLL, 80.0000MHz
     Ext. Modules:    I2C RTC (DS1307) - ac:RTC2
                      http://www.mikroe.com/eng/products/view/197/rtc2-board/
                      LCD 2x16 chars - ac:LCD
                      http://www.mikroe.com/eng/products/view/277/various-components/
     SW:              mikroC PRO for dsPIC
                      http://www.mikroe.com/eng/products/view/231/mikroc-pro-for-dspic30-33-and-pic24/
 * NOTES:
     - For proper I2C communication, pins on PORTC must be in the pull-up mode,
       RF3 - pin 6 DS1307 - SCL,
       RF2 - pin 5 DS1307 - SDA,
       and the LEDs on board switched OFF!
*/

void main() {

   ADPCFG = 0xFFFF;

   Delay_ms(1000);

   I2C1_Init(100000);     // initialize full master mode
   I2C1_Start();          // issue start signal
   I2C1_Write(0xD0);      // address DS1307
   I2C1_Write(0);         // start from word at address (REG0)
   I2C1_Write(0x80);      // write $80 to REG0. (pause counter + 0 sec)
   I2C1_Write(0);         // write 0 to minutes word to (REG1)
   I2C1_Write(0x12);      // write 17 to hours word (24-hours mode)(REG2)
   I2C1_Write(0x05);      // write 2 - Monday (REG3)
   I2C1_Write(0x29);      // write 4 to date word (REG4)
   I2C1_Write(0x11);      // write 5 (May) to month word (REG5)
   I2C1_Write(0x10);      // write 09 to year word (REG6)
   I2C1_Stop();           // issue stop signal

   I2C1_Start();          // issue start signal
   I2C1_Write(0xD0);      // address DS1307
   I2C1_Write(0);         // start from word at address 0
   I2C1_Write(0);         // write 0 to REG0 (enable counting + 0 sec)
   I2C1_Stop();           // issue stop signal
}